Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(460)

Unified Diff: samplecode/SampleApp.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « samplecode/SampleAnimator.cpp ('k') | samplecode/SampleApp.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: samplecode/SampleApp.h
diff --git a/samplecode/SampleApp.h b/samplecode/SampleApp.h
index 1f8c33389a348463e69a449ce13e198159ed857b..d8724955e07437aae4a7323ff93c6dc4d6e3c9fd 100644
--- a/samplecode/SampleApp.h
+++ b/samplecode/SampleApp.h
@@ -87,10 +87,10 @@ public:
// at least once before first draw (after init)
virtual void windowSizeChanged(SampleWindow* win) = 0;
// return the GrContext backing gpu devices (NULL if not built with GPU support)
virtual GrContext* getGrContext() = 0;
// return the GrRenderTarget backing gpu devices (NULL if not built with GPU support)
virtual GrRenderTarget* getGrRenderTarget() = 0;
private:
typedef SkRefCnt INHERITED;
@@ -100,11 +100,11 @@ public:
virtual ~SampleWindow();
SkSurface* createSurface() override {
- SkSurface* surface = NULL;
+ SkSurface* surface = nullptr;
if (fDevManager) {
surface = fDevManager->createSurface(fDeviceType, this);
}
- if (NULL == surface) {
+ if (nullptr == surface) {
surface = this->INHERITED::createSurface();
}
return surface;
@@ -87,10 +87,10 @@ public:
// at least once before first draw (after init)
virtual void windowSizeChanged(SampleWindow* win) = 0;
- // return the GrContext backing gpu devices (NULL if not built with GPU support)
+ // return the GrContext backing gpu devices (nullptr if not built with GPU support)
virtual GrContext* getGrContext() = 0;
@@ -87,10 +87,10 @@ public:
virtual GrContext* getGrContext() = 0;
- // return the GrRenderTarget backing gpu devices (NULL if not built with GPU support)
+ // return the GrRenderTarget backing gpu devices (nullptr if not built with GPU support)
virtual GrRenderTarget* getGrRenderTarget() = 0;
private:
« no previous file with comments | « samplecode/SampleAnimator.cpp ('k') | samplecode/SampleApp.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698